@@ -1,4 +1,4 @@
-# Copyright 2010-2014 Meik Michalke <meik.michalke@hhu.de>
+# Copyright 2010-2017 Meik Michalke <meik.michalke@hhu.de>
 #
 # This file is part of the R package koRpus.
 #
@@ -90,8 +90,8 @@
 #' and used. Set \code{force.lang=get.kRp.env(lang=TRUE)} or to any other valid value, if you want to forcibly overwrite this
 #' default behaviour, and only then. See \code{\link[koRpus:kRp.POS.tags]{kRp.POS.tags}} for all supported languages.
 #'
-#' @param txt An object of either class \code{\link[koRpus]{kRp.tagged-class}}, \code{\link[koRpus]{kRp.txt.freq-class}},
-#'    \code{\link[koRpus]{kRp.analysis-class}} or \code{\link[koRpus]{kRp.txt.trans-class}}, containing the tagged text to be analyzed.
+#' @param txt An object of either class \code{\link[koRpus:kRp.tagged-class]{kRp.tagged}}, \code{\link[koRpus:kRp.txt.freq-class]{kRp.txt.freq}},
+#'    \code{\link[koRpus:kRp.analysis-class]{kRp.analysis}} or \code{\link[koRpus:kRp.txt.trans-class]{kRp.txt.trans}}, containing the tagged text to be analyzed.
 #'    If \code{txt} is of class character, it is assumed to be the raw text to be analyzed.
 #' @param segment An integer value for MSTTR, defining how many tokens should form one segment.
 #' @param factor.size A real number between 0 and 1, defining the MTLD factor size.
@@ -114,19 +114,22 @@
 #' @param char.steps An integer value defining the step size for characteristic curves, in tokens.
 #' @param log.base A numeric value defining the base of the logarithm. See \code{\link[base:log]{log}} for details.
 #' @param force.lang A character string defining the language to be assumed for the text, by force. See details.
-#' @param keep.tokens Logical. If \code{TRUE} all raw tokens and types will be preserved in the resulting object, in a slot called 
+#' @param keep.tokens Logical. If \code{TRUE}, all raw tokens and types will be preserved in the resulting object, in a slot called 
 #'    \code{tt}. For the types, also their frequency in the analyzed text will be listed.
+#' @param type.index Logical. If \code{TRUE}, the \code{tt} slot will contain two named lists of all types with the indices where that particular
+#'    type is to be found in the original tagged text (\code{type.in.txt}) or the list of tokens in these results (\code{type.in.result}),
+#'    respectively.
 #' @param corp.rm.class A character vector with word classes which should be dropped. The default value
 #'    \code{"nonpunct"} has special meaning and will cause the result of
 #'    \code{kRp.POS.tags(lang, c("punct","sentc"), list.classes=TRUE)} to be used.
 #' @param corp.rm.tag A character vector with POS tags which should be dropped.
 #' @param quiet Logical. If \code{FALSE}, short status messages will be shown.
 #'    \code{TRUE} will also suppress all potential warnings regarding the validation status of measures.
-#' @return An object of class \code{\link[koRpus]{kRp.TTR-class}}.
+#' @return An object of class \code{\link[koRpus:kRp.TTR-class]{kRp.TTR}}.
 # @author m.eik michalke \email{meik.michalke@@hhu.de}
 #' @keywords LD
 #' @seealso \code{\link[koRpus:kRp.POS.tags]{kRp.POS.tags}},
-#'    \code{\link[koRpus]{kRp.tagged-class}}, \code{\link[koRpus]{kRp.TTR-class}}
+#'    \code{\link[koRpus:kRp.tagged-class]{kRp.tagged}}, \code{\link[koRpus:kRp.TTR-class]{kRp.TTR}}
 #' @references
 #'    Covington, M.A. & McFall, J.D. (2010). Cutting the Gordian Knot: The Moving-Average Type-Token Ratio (MATTR). 
 #'      \emph{Journal of Quantitative Linguistics}, 17(2), 94--100.
@@ -146,7 +149,10 @@
 #' @export
 #' @examples
 #' \dontrun{
-#' lex.div(tagged.text)
+#' ld.results <- lex.div(tagged.text)
+#' 
+#' # there is [ and [[ methods for these objects
+#' ld.results[["MSTTR"]]
 #' }
 
 #' @param ... Only used for the method generic.
@@ -172,13 +178,14 @@ setMethod("lex.div", signature(txt="kRp.taggedText"), function(txt, segment=100,
     char.steps=5, log.base=10,
     force.lang=NULL,
     keep.tokens=FALSE,
+    type.index=FALSE,
     corp.rm.class="nonpunct",
     corp.rm.tag=c(), quiet=FALSE){
 
     lex.div.results <- kRp.lex.div.formulae(txt=txt, segment=segment, factor.size=factor.size, min.tokens=min.tokens,
       MTLDMA.steps=MTLDMA.steps, rand.sample=rand.sample, window=window, case.sens=case.sens, lemmatize=lemmatize, detailed=detailed,
       measure=measure, char=char, char.steps=char.steps, log.base=log.base, force.lang=force.lang,
-      keep.tokens=keep.tokens, corp.rm.class=corp.rm.class, corp.rm.tag=corp.rm.tag, quiet=quiet)
+      keep.tokens=keep.tokens, type.index=type.index, corp.rm.class=corp.rm.class, corp.rm.tag=corp.rm.tag, quiet=quiet)
 
     return(lex.div.results)
   }
@@ -195,13 +202,14 @@ setMethod("lex.div", signature(txt="character"), function(txt, segment=100,
     char.steps=5, log.base=10,
     force.lang=NULL,
     keep.tokens=FALSE,
+    type.index=FALSE,
     corp.rm.class="nonpunct",
     corp.rm.tag=c(), quiet=FALSE){
 
     lex.div.results <- kRp.lex.div.formulae(txt=txt, segment=segment, factor.size=factor.size, min.tokens=min.tokens,
       MTLDMA.steps=MTLDMA.steps, rand.sample=rand.sample, window=window, case.sens=case.sens, lemmatize=lemmatize, detailed=detailed,
       measure=measure, char=char, char.steps=char.steps, log.base=log.base, force.lang=force.lang,
-      keep.tokens=keep.tokens, corp.rm.class=corp.rm.class, corp.rm.tag=corp.rm.tag, quiet=quiet)
+      keep.tokens=keep.tokens, type.index=type.index, corp.rm.class=corp.rm.class, corp.rm.tag=corp.rm.tag, quiet=quiet)
 
     return(lex.div.results)
   }
@@ -222,3 +230,29 @@ setMethod("lex.div", signature(txt="missing"), function(txt, measure){
     return(invisible(NULL))
   }
 )
+
+#' @rdname lex.div-methods
+#' @param x An object of class \code{kRp.TTR}.
+#' @param i Defines the row selector (\code{[}) or the name to match (\code{[[}).
+#' @export
+#' @docType methods
+#' @aliases
+#'    [,kRp.TTR,ANY-method
+setMethod("[",
+  signature=signature(x="kRp.TTR"),
+  function (x, i){
+    return(summary(x, flat=TRUE)[i])
+  }
+)
+
+#' @rdname lex.div-methods
+#' @export
+#' @docType methods
+#' @aliases
+#'    [[,kRp.TTR,ANY-method
+setMethod("[[",
+  signature=signature(x="kRp.TTR"),
+  function (x, i){
+    return(summary(x, flat=TRUE)[[i]])
+  }
+)
