@@ -1,4 +1,4 @@
-# Copyright 2010-2014 Meik Michalke <meik.michalke@hhu.de>
+# Copyright 2010-2018 Meik Michalke <meik.michalke@hhu.de>
 #
 # This file is part of the R package koRpus.
 #
@@ -35,8 +35,9 @@
 #'    to manually tweak options for tokenizing and POS tagging yourself. In that case, you need to provide a full set of options with the \code{TT.options}
 #'    parameter.
 #' @param rm.sgml Logical, whether SGML tags should be ignored and removed from output
-#' @param lang A character string naming the language of the analyzed corpus. See \code{\link[koRpus:kRp.POS.tags]{kRp.POS.tags}} for all supported languages.
-#'    If set to \code{"kRp.env"} this is got from \code{\link[koRpus:get.kRp.env]{get.kRp.env}}.
+#' @param lang A character string naming the language of the analyzed corpus. See \code{\link[koRpus:kRp.POS.tags]{kRp.POS.tags}} and
+#'    \code{\link[koRpus:available.koRpus.lang]{available.koRpus.lang}}for all supported languages. If set to \code{"kRp.env"} this is
+#'    fetched from \code{\link[koRpus:get.kRp.env]{get.kRp.env}}.
 #' @param apply.sentc.end Logical, whethter the tokens defined in \code{sentc.end} should be searched and set to a sentence ending tag.
 #' @param sentc.end A character vector with tokens indicating a sentence ending. This adds to TreeTaggers results, it doesn't really replace them.
 #' @param encoding A character string defining the character encoding of the input file, like  \code{"Latin1"} or \code{"UTF-8"}. If \code{NULL},
@@ -45,15 +46,8 @@
 #'    or you give a full set of valid options:
 #'    \itemize{
 #'      \item {\code{path}} {Mandatory: The absolute path to the TreeTagger root directory. That is where its subfolders \code{bin}, \code{cmd} and \code{lib} are located.}
-#'      \item {\code{preset}} {Optional: If you choose one of the pre-defined presets here:
-#'      \itemize{
-#'        \item {\code{"de"}} {German}
-#'        \item {\code{"en"}} {English}
-#'        \item {\code{"es"}} {Spanish}
-#'        \item {\code{"fr"}} {French}
-#'        \item {\code{"it"}} {Italian}
-#'        \item {\code{"ru"}} {Russian}
-#'      }
+#'      \item {\code{preset}} {Optional: If you choose one of the pre-defined presets of one of the available language packages (like \code{"de"} for German, see
+#'        \code{\link[koRpus:available.koRpus.lang]{available.koRpus.lang}} for details),
 #'        you can omit all the following elements, because they will be filled with defaults. Of course this only makes sense if you have a
 #'        working default installation. Note that since koRpus 0.07-1, UTF-8 is the global default encoding.}
 #'      \item {\code{tokenizer}} {Mandatory: A character string, naming the tokenizer to be called. Interpreted relative to \code{path/cmd/}.}
@@ -68,7 +62,7 @@
 #'      \item {\code{lexicon}} {Optional: A character string, naming the lexicon file to be used. Interpreted relative to \code{path/lib/}.}
 #'      \item {\code{lookup}} {Optional: A character string, naming the lexicon lookup command. Interpreted relative to \code{path/cmd/}.}
 #'      \item {\code{filter}} {Optional: A character string, naming the output filter to be used. Interpreted relative to \code{path/cmd/}.}
-#'      \item {\code{no.unknown}} {Optional: Logical, can be used to toggle the \code{"-no-unknown"} option of TreeTagger (defaults of \code{FALSE}.}
+#'      \item {\code{no.unknown}} {Optional: Logical, can be used to toggle the \code{"-no-unknown"} option of TreeTagger (defaults to \code{FALSE}).}
 #'      \item {\code{splitter}} {Optional: A character string, naming the splitter to be called (before the tokenizer). Interpreted relative to \code{path/cmd/}.}
 #'      \item {\code{splitter.opts}} {Optional: A character string with the options to hand over to the splitter.}
 #'    }
@@ -88,13 +82,17 @@
 #'    \code{stopwords=tm::stopwords("en")} to use the english stopwords provided by the \code{tm} package.
 #' @param stemmer A function or method to perform stemming. For instance, you can set \code{SnowballC::wordStem} if you have
 #'    the \code{SnowballC} package installed. As of now, you cannot provide further arguments to this function.
-#' @return An object of class \code{\link[koRpus]{kRp.tagged-class}}. If \code{debug=TRUE}, prints internal variable settings and attempts to return the
+#' @param doc_id Character string, optional identifier of the particular document. Will be added to the \code{desc} slot, and as a factor to the \code{"doc_id"} column
+#'    of the \code{TT.res} slot.
+#' @param add.desc Logical. If \code{TRUE}, the tag description (column \code{"desc"} of the data.frame) will be added directly
+#'    to the resulting object. If set to \code{"kRp.env"} this is fetched from \code{\link[koRpus:get.kRp.env]{get.kRp.env}}.
+#' @return An object of class \code{\link[koRpus:kRp.tagged-class]{kRp.tagged}}. If \code{debug=TRUE}, prints internal variable settings and attempts to return the
 #'    original output if the TreeTagger system call in a matrix.
 #' @author m.eik michalke \email{meik.michalke@@hhu.de}, support for various laguages was contributed by Earl Brown (Spanish), Alberto Mirisola (Italian) and
 #'    Alexandre Brulet (French).
 #' @keywords misc
 #' @seealso \code{\link[koRpus:freq.analysis]{freq.analysis}}, \code{\link[koRpus:get.kRp.env]{get.kRp.env}},
-#' \code{\link[koRpus]{kRp.tagged-class}}
+#' \code{\link[koRpus:kRp.tagged-class]{kRp.tagged}}
 #' @references
 #' Schmid, H. (1994). Probabilistic part-of-speec tagging using decision trees. In
 #'    \emph{International Conference on New Methods in Language Processing}, Manchester, UK, 44--49.
@@ -132,7 +130,7 @@
 
 treetag <- function(file, treetagger="kRp.env", rm.sgml=TRUE, lang="kRp.env",
   apply.sentc.end=TRUE, sentc.end=c(".","!","?",";",":"), encoding=NULL, TT.options=NULL, debug=FALSE, TT.tknz=TRUE,
-  format="file", stopwords=NULL, stemmer=NULL){
+  format="file", stopwords=NULL, stemmer=NULL, doc_id=NA, add.desc="kRp.env"){
 
   # TreeTagger uses slightly different presets on windows and unix machines,
   # so we'll need to check the OS first
@@ -158,6 +156,9 @@ treetag <- function(file, treetagger="kRp.env", rm.sgml=TRUE, lang="kRp.env",
   if(identical(lang, "kRp.env")){
     lang <- get.kRp.env(lang=TRUE)
   } else {}
+  if(identical(add.desc, "kRp.env")){
+    add.desc <- get.kRp.env(add.desc=TRUE)
+  } else {}
 
   if(identical(treetagger, "tokenize")){
     stop(simpleError("Sorry, you can't use treetag() and tokenize() at the same time!"))
@@ -165,7 +166,7 @@ treetag <- function(file, treetagger="kRp.env", rm.sgml=TRUE, lang="kRp.env",
 
   # TreeTagger won't be able to use a connection object, so to make these usable,
   # we have to write its content to a temporary file first
-  if(inherits(file, "connection") | identical(format, "obj")){
+  if(any(inherits(file, "connection"), identical(format, "obj"))){
     takeAsFile <- dumpTextToTempfile(text=file, encoding=encoding)
     if(!isTRUE(debug)){
       on.exit(unlink(takeAsFile), add=TRUE)
@@ -224,27 +225,27 @@ treetag <- function(file, treetagger="kRp.env", rm.sgml=TRUE, lang="kRp.env",
     } else {}
 
     if("tokenizer" %in% names(TT.options)){
-      TT.tokenizer    <- file.path(TT.cmd, TT.options[["tokenizer"]])
-    } else {}
-    # check if path works
-    check.file(TT.tokenizer, mode="exist")
+      TT.tokenizer    <- check_toggle_utf8(file_utf8=TT.options[["tokenizer"]], dir=TT.cmd)
+    } else {
+      TT.tokenizer    <- check_toggle_utf8(file_utf8=TT.tokenizer)
+    }
     if("tagger" %in% names(TT.options)){
       TT.tagger      <- file.path(TT.bin, TT.options[["tagger"]])
     } else {}
     # check if path works
     check.file(TT.tagger, mode="exist")
     if("pre.tagger" %in% names(TT.options)){
-      TT.pre.tagger <- TT.options[["pre.tagger"]]
+      TT.pre.tagger  <- TT.options[["pre.tagger"]]
     } else {
       if(!isTRUE(have.preset)){
         TT.pre.tagger <- c()
       } else {}
     }
     if("params" %in% names(TT.options)){
-      TT.params      <- file.path(TT.lib, TT.options[["params"]])
-    } else {}
-    # check if path works
-    check.file(TT.params, mode="exist")
+      TT.params      <- check_toggle_utf8(file_utf8=TT.options[["params"]], dir=TT.lib)
+    } else {
+      TT.params      <- check_toggle_utf8(file_utf8=TT.params)
+    }
 
     # check the input encoding
     input.enc <- ifelse(
@@ -284,15 +285,14 @@ treetag <- function(file, treetagger="kRp.env", rm.sgml=TRUE, lang="kRp.env",
     }
 
     if("abbrev" %in% names(TT.options)){
-      TT.abbrev      <- file.path(TT.lib, TT.options[["abbrev"]])
-      check.file(TT.abbrev, mode="exist")
-      TT.tknz.opts    <- paste(TT.tknz.opts, "-a", TT.abbrev)
+      TT.abbrev      <- check_toggle_utf8(file_utf8=TT.options[["abbrev"]], dir=TT.lib)
+      TT.tknz.opts   <- paste(TT.tknz.opts, "-a", TT.abbrev)
     } else {
       if(isTRUE(have.preset) & !identical(TT.abbrev, c())){
-        TT.tknz.opts    <- paste(TT.tknz.opts, "-a", TT.abbrev)
-        check.file(TT.abbrev, mode="exist")
+        TT.tknz.opts <- paste(TT.tknz.opts, "-a", TT.abbrev)
+        TT.abbrev    <- check_toggle_utf8(file_utf8=TT.abbrev)
       } else {
-        TT.abbrev <- eval(formals(tokenize)[["abbrev"]])
+        TT.abbrev    <- eval(formals(tokenize)[["abbrev"]])
       }
     }
 
@@ -308,7 +308,7 @@ treetag <- function(file, treetagger="kRp.env", rm.sgml=TRUE, lang="kRp.env",
         if(!this.opt %in% given.tknz.options) {
           TT.tknz.opts[[this.opt]] <- eval(formals(tokenize)[[this.opt]])
           if(isTRUE(debug)){
-            message(paste0(this.opt, "=", paste0(TT.tknz.opts[[this.opt]], collapse=", ")))
+            message(paste0("        ", this.opt, "=", paste0(TT.tknz.opts[[this.opt]], collapse=", ")))
           } else {}
         } else {}
       }
@@ -340,8 +340,8 @@ treetag <- function(file, treetagger="kRp.env", rm.sgml=TRUE, lang="kRp.env",
       )
       # TreeTagger can produce mixed encoded results if fed with UTF-8 in Latin1 mode
       tknz.results <- iconv(tknz.results, from="UTF-8", to=input.enc)
-      message(paste0("Assuming '", input.enc, "' as encoding for the input file. If the results turn out to be erroneous, check the file for invalid characters, e.g. em.dashes or fancy quotes, and/or consider setting 'encoding' manually."))
-      cat(paste(tknz.results, collapse="\n"), file=tknz.tempfile)
+      on.exit(message(paste0("Assuming '", input.enc, "' as encoding for the input file. If the results turn out to be erroneous, check the file for invalid characters, e.g. em.dashes or fancy quotes, and/or consider setting 'encoding' manually.")))
+      cat(paste(tknz.results, collapse="\n"), "\n", file=tknz.tempfile)
       if(!isTRUE(debug)){
         on.exit(unlink(tknz.tempfile), add=TRUE)
       } else {}
@@ -405,16 +405,16 @@ treetag <- function(file, treetagger="kRp.env", rm.sgml=TRUE, lang="kRp.env",
       }
     } else {
       if(isTRUE(TT.tknz)){
-        TT.call.file <- paste0("\"", takeAsFile, "\"")
+        TT.call.file <- winPath(paste0("\"", takeAsFile, "\""))
         if(isTRUE(use.splitter)){
-          TT.splitter <- paste(TT.splitter, TT.call.file, TT.splitter.opts)
+          TT.splitter <- paste(winPath(TT.splitter), TT.call.file, TT.splitter.opts)
           TT.call.file <- ""
         } else {}
-        sys.tt.call <- paste(TT.splitter, "perl ", TT.tokenizer, TT.tknz.opts, TT.call.file, "|",
-          TT.lookup.command, TT.pre.tagger, TT.tagger, TT.params, TT.opts, TT.filter.command)
+        sys.tt.call <- paste(TT.splitter, "perl ", winPath(TT.tokenizer), TT.tknz.opts, TT.call.file, "|",
+          winPath(TT.lookup.command), TT.pre.tagger, winPath(TT.tagger), winPath(TT.params), TT.opts, TT.filter.command)
       } else {
-        sys.tt.call <- paste("type ", tknz.tempfile, "|",
-          TT.lookup.command, TT.pre.tagger, TT.tagger, TT.params, TT.opts, TT.filter.command)
+        sys.tt.call <- paste("type ", winPath(tknz.tempfile), "|",
+          winPath(TT.lookup.command), TT.pre.tagger, winPath(TT.tagger), winPath(TT.params), TT.opts, TT.filter.command)
       }
     }
 
@@ -463,7 +463,8 @@ treetag <- function(file, treetagger="kRp.env", rm.sgml=TRUE, lang="kRp.env",
   } else {
     tagged.text <- shell(sys.tt.call, translate=TRUE, ignore.stderr=TRUE, intern=TRUE)
   }
-  tagged.text <- enc2utf8(tagged.text)
+  # TreeTagger should return UTF-8; explicitly declare it so there's no doubt about it
+  Encoding(tagged.text) <- "UTF-8"
 
   ## workaround
   # in seldom cases TreeTagger seems to return duplicate tab stops
@@ -474,7 +475,26 @@ treetag <- function(file, treetagger="kRp.env", rm.sgml=TRUE, lang="kRp.env",
     tagged.text <- tagged.text[grep("^[^<]", tagged.text)]
   } else {}
 
-  tagged.mtrx <- matrix(unlist(strsplit(tagged.text, "\t")), ncol=3, byrow=TRUE, dimnames=list(c(),c("token","tag","lemma")))
+  ## try to catch error in local TreeTagger setup
+  # when TreeTagger is not set up correctly, the system call will not fail loudly
+  # but simply not return any useful data. this in turn will definitely cause
+  # treetag() to fail with an error. we'll make it obvious that probably not
+  # not koRpus is to blame for this -- but it could also be preset bugs!
+  tagged.text <- unlist(strsplit(tagged.text, "\t"))
+  if(is.null(tagged.text)){
+    stop(simpleError(paste0(
+      "Awww, this should not happen: TreeTagger didn't return any useful data.\n",
+      "  This can happen if the local TreeTagger setup is incomplete or different from what presets expected.\n",
+      "  You should re-run your command with the option 'debug=TRUE'. That will print all relevant configuration.\n",
+      "  Look for a line starting with 'sys.tt.call:' and try to execute the full command following it in a\n",
+      "  command line terminal. Do not close this R session in the meantime, as 'debug=TRUE' will keep temporary\n",
+      "  files that might be needed.\n",
+      "  If running the command after 'sys.tt.call:' does fail, you'll need to fix the TreeTagger setup.\n",
+      "  If it does *not* fail but produce a table with proper results, please contact the author!"
+    )))
+  } else {
+    tagged.mtrx <- matrix(tagged.text, ncol=3, byrow=TRUE, dimnames=list(c(),c("token","tag","lemma")))
+  }
 
   # add sentence endings as defined
   if(isTRUE(apply.sentc.end)){
@@ -488,20 +508,23 @@ treetag <- function(file, treetagger="kRp.env", rm.sgml=TRUE, lang="kRp.env",
   } else {}
 
   # add word classes, comments and numer of letters ("wclass", "desc", "lttr")
-  tagged.mtrx <- treetag.com(tagged.mtrx, lang=lang)
+  tagged.mtrx <- treetag.com(tagged.mtrx, lang=lang, add.desc=add.desc)
 
   # probably apply stopword detection and stemming
   tagged.mtrx <- stopAndStem(tagged.mtrx, stopwords=stopwords, stemmer=stemmer, lowercase=TRUE)
 
-  results <- new("kRp.tagged", lang=lang, TT.res=tagged.mtrx)
+  # add columns "idx", "sntc" and "doc_id"
+  tagged.mtrx <- indexSentenceDoc(tagged.mtrx, lang=lang, doc_id=doc_id)
+
+  results <- kRp_tagged(lang=lang, TT.res=tagged.mtrx)
   ## descriptive statistics
   if(is.null(encoding)){
     encoding <- ""
   } else {}
-  txt.vector <- readLines(takeAsFile, encoding=encoding)
+  txt.vector <- readLines(takeAsFile, encoding=encoding, warn=FALSE)
   # force text into UTF-8 format
   txt.vector <- enc2utf8(txt.vector)
-  results@desc <- basic.tagged.descriptives(results, lang=lang, txt.vector=txt.vector)
+  results@desc <- basic.tagged.descriptives(results, lang=lang, txt.vector=txt.vector, doc_id=doc_id)
 
   return(results)
 }
